
// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#include <sbkpep.h>
#include <sbkpepbuffer.h>

#define PYSIDE6_COMOPT_COMPRESS 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "kcalendarcore_python.h"

// main header
#include "kcalendarcore_incidence_wrapper.h"

// Wrappers providing overrides
#include "kcalendarcore_incidencebase_wrapper.h"
#include "kcalendarcore_customproperties_wrapper.h"
#include "kcalendarcore_recurrence_recurrenceobserver_wrapper.h"

// Argument includes
#include <QList>
#include <QString>
#include <QStringList>
#include <QtCore/qlatin1stringview.h>
#include <attachment.h>
#include <conference.h>
#include <duration.h>
#include <incidence.h>
#include <incidencebase.h>
#include <qbytearray.h>
#include <qdatastream.h>
#include <qdatetime.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qtimezone.h>
#include <recurrence.h>

#include <algorithm>
#include <cctype>
#include <cstring>
#include <iterator>
#include <set>
#include <type_traits>
#include <typeinfo>

using namespace KCalendarCore;

extern "C" {
static PyTypeObject *Sbk_KCalendarCore_Incidence_TypeF(void)
{
    return SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX].type;
}
} // extern "C"

// Native ---------------------------------------------------------

void IncidenceWrapper::resetPyMethodCache()
{
    std::fill(m_PyMethodCache.begin(), m_PyMethodCache.end(), nullptr);
}

::KCalendarCore::Incidence * IncidenceWrapper::clone() const
{
    static const char *funcName = "clone";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_Incidence_TypeF(), gil, funcName, m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("Incidence.clone");
        return nullptr;
    }
    return sbk_o_clone("Incidence", funcName, gil, pyOverride);
}

::KCalendarCore::Incidence * IncidenceWrapper::sbk_o_clone([[maybe_unused]] const char *ownerClassName, [[maybe_unused]] const char *funcName, [[maybe_unused]] Shiboken::GilState &gil, [[maybe_unused]] const Shiboken::AutoDecRef &pyOverride)
{
#if defined(PYPY_VERSION)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION)
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, PepType_GetFullyQualifiedNameStr(Shiboken::SbkType< KCalendarCore::Incidence >()), Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::KCalendarCore::Incidence *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void IncidenceWrapper::customPropertyUpdate()
{
    static const char *funcName = "customPropertyUpdate";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_Incidence_TypeF(), gil, funcName, m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::IncidenceBase::customPropertyUpdate();
    }
    CustomPropertiesWrapper::sbk_o_customPropertyUpdate("Incidence", funcName, gil, pyOverride);
}

void IncidenceWrapper::customPropertyUpdated()
{
    static const char *funcName = "customPropertyUpdated";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_Incidence_TypeF(), gil, funcName, m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::IncidenceBase::customPropertyUpdated();
    }
    CustomPropertiesWrapper::sbk_o_customPropertyUpdate("Incidence", funcName, gil, pyOverride);
}

::QDateTime IncidenceWrapper::dateTime(::KCalendarCore::IncidenceBase::DateTimeRole role) const
{
    static const char *funcName = "dateTime";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_Incidence_TypeF(), gil, funcName, m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("Incidence.dateTime");
        return {};
    }
    return IncidenceBaseWrapper::sbk_o_dateTime("Incidence", funcName, gil, pyOverride, role);
}

void IncidenceWrapper::deserialize(::QDataStream & in)
{
    static const char *funcName = "deserialize";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_Incidence_TypeF(), gil, funcName, m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::Incidence::deserialize(in);
    }
    IncidenceBaseWrapper::sbk_o_deserialize("Incidence", funcName, gil, pyOverride, in);
}

::QDateTime IncidenceWrapper::dtStart() const
{
    // This method belongs to a property.
    static const char *funcName = "1:dtStart";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_Incidence_TypeF(), gil, funcName, m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::IncidenceBase::dtStart();
    }
    return IncidenceBaseWrapper::sbk_o_dtStart("Incidence", funcName, gil, pyOverride);
}

::QDateTime IncidenceWrapper::endDateForStart(const ::QDateTime & startDt) const
{
    static const char *funcName = "endDateForStart";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_Incidence_TypeF(), gil, funcName, m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::Incidence::endDateForStart(startDt);
    }
    return sbk_o_endDateForStart("Incidence", funcName, gil, pyOverride, startDt);
}

::QDateTime IncidenceWrapper::sbk_o_endDateForStart([[maybe_unused]] const char *ownerClassName, [[maybe_unused]] const char *funcName, [[maybe_unused]] Shiboken::GilState &gil, [[maybe_unused]] const Shiboken::AutoDecRef &pyOverride, [[maybe_unused]] const ::QDateTime & startDt)
{
#if !defined(PYPY_VERSION) && (!defined(Py_LIMITED_API) || Py_LIMITED_API >= 0x030C0000)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), &startDt)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), &startDt)
    ));
#endif

#if !defined(PYPY_VERSION) && (!defined(Py_LIMITED_API) || Py_LIMITED_API >= 0x030C0000)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return {};
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, PepType_GetFullyQualifiedNameStr(Shiboken::SbkType< QDateTime >()), Py_TYPE(pyResult)->tp_name);
        return {};
    }
    ::QDateTime cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool IncidenceWrapper::equals(const ::KCalendarCore::IncidenceBase & incidence) const
{
    static const char *funcName = "equals";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_Incidence_TypeF(), gil, funcName, m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::Incidence::equals(incidence);
    }
    return IncidenceBaseWrapper::sbk_o_equals("Incidence", funcName, gil, pyOverride, incidence);
}

::QLatin1String IncidenceWrapper::iconName(const ::QDateTime & recurrenceId) const
{
    static const char *funcName = "iconName";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_Incidence_TypeF(), gil, funcName, m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("Incidence.iconName");
        return ::QLatin1String();
    }
    return sbk_o_iconName("Incidence", funcName, gil, pyOverride, recurrenceId);
}

::QLatin1String IncidenceWrapper::sbk_o_iconName([[maybe_unused]] const char *ownerClassName, [[maybe_unused]] const char *funcName, [[maybe_unused]] Shiboken::GilState &gil, [[maybe_unused]] const Shiboken::AutoDecRef &pyOverride, [[maybe_unused]] const ::QDateTime & recurrenceId)
{
#if !defined(PYPY_VERSION) && (!defined(Py_LIMITED_API) || Py_LIMITED_API >= 0x030C0000)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), &recurrenceId)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), &recurrenceId)
    ));
#endif

#if !defined(PYPY_VERSION) && (!defined(Py_LIMITED_API) || Py_LIMITED_API >= 0x030C0000)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return ::QLatin1String();
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QLatin1String_IDX], pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, "QLatin1String", Py_TYPE(pyResult)->tp_name);
        return ::QLatin1String();
    }
    ::QLatin1String cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QLatin1String IncidenceWrapper::mimeType() const
{
    static const char *funcName = "mimeType";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_Incidence_TypeF(), gil, funcName, m_PyMethodCache[9], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("Incidence.mimeType");
        return ::QLatin1String();
    }
    return IncidenceBaseWrapper::sbk_o_mimeType("Incidence", funcName, gil, pyOverride);
}

::QDateTime IncidenceWrapper::recurrenceId() const
{
    static const char *funcName = "recurrenceId";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_Incidence_TypeF(), gil, funcName, m_PyMethodCache[10], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::Incidence::recurrenceId();
    }
    return IncidenceBaseWrapper::sbk_o_dtStart("Incidence", funcName, gil, pyOverride);
}

void IncidenceWrapper::recurrenceUpdated(::KCalendarCore::Recurrence * recurrence)
{
    static const char *funcName = "recurrenceUpdated";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_Incidence_TypeF(), gil, funcName, m_PyMethodCache[11], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::Incidence::recurrenceUpdated(recurrence);
    }
    RecurrenceObserverWrapper::sbk_o_recurrenceUpdated("Incidence", funcName, gil, pyOverride, recurrence);
}

bool IncidenceWrapper::recursOn(const ::QDate & date, const ::QTimeZone & timeZone) const
{
    static const char *funcName = "recursOn";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_Incidence_TypeF(), gil, funcName, m_PyMethodCache[12], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::Incidence::recursOn(date, timeZone);
    }
    return sbk_o_recursOn("Incidence", funcName, gil, pyOverride, date, timeZone);
}

bool IncidenceWrapper::sbk_o_recursOn([[maybe_unused]] const char *ownerClassName, [[maybe_unused]] const char *funcName, [[maybe_unused]] Shiboken::GilState &gil, [[maybe_unused]] const Shiboken::AutoDecRef &pyOverride, [[maybe_unused]] const ::QDate & date, [[maybe_unused]] const ::QTimeZone & timeZone)
{
#if !defined(PYPY_VERSION) && (!defined(Py_LIMITED_API) || Py_LIMITED_API >= 0x030C0000)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), &date),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]), &timeZone)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), &date),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]), &timeZone)
    ));
#endif

#if !defined(PYPY_VERSION) && (!defined(Py_LIMITED_API) || Py_LIMITED_API >= 0x030C0000)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void IncidenceWrapper::serialize(::QDataStream & out) const
{
    static const char *funcName = "serialize";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_Incidence_TypeF(), gil, funcName, m_PyMethodCache[13], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::Incidence::serialize(out);
    }
    IncidenceBaseWrapper::sbk_o_deserialize("Incidence", funcName, gil, pyOverride, out);
}

void IncidenceWrapper::setAllDay(bool allDay)
{
    static const char *funcName = "setAllDay";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_Incidence_TypeF(), gil, funcName, m_PyMethodCache[14], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::Incidence::setAllDay(allDay);
    }
    IncidenceBaseWrapper::sbk_o_setAllDay("Incidence", funcName, gil, pyOverride, allDay);
}

void IncidenceWrapper::setDateTime(const ::QDateTime & dateTime, ::KCalendarCore::IncidenceBase::DateTimeRole role)
{
    static const char *funcName = "setDateTime";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_Incidence_TypeF(), gil, funcName, m_PyMethodCache[15], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("Incidence.setDateTime");
        return;
    }
    IncidenceBaseWrapper::sbk_o_setDateTime("Incidence", funcName, gil, pyOverride, dateTime, role);
}

void IncidenceWrapper::setDtStart(const ::QDateTime & dt)
{
    static const char *funcName = "setDtStart";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_Incidence_TypeF(), gil, funcName, m_PyMethodCache[16], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::Incidence::setDtStart(dt);
    }
    IncidenceBaseWrapper::sbk_o_setDtStart("Incidence", funcName, gil, pyOverride, dt);
}

void IncidenceWrapper::setDuration(const ::KCalendarCore::Duration & duration)
{
    static const char *funcName = "setDuration";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_Incidence_TypeF(), gil, funcName, m_PyMethodCache[17], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::IncidenceBase::setDuration(duration);
    }
    IncidenceBaseWrapper::sbk_o_setDuration("Incidence", funcName, gil, pyOverride, duration);
}

void IncidenceWrapper::setLastModified(const ::QDateTime & lm)
{
    static const char *funcName = "setLastModified";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_Incidence_TypeF(), gil, funcName, m_PyMethodCache[18], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::Incidence::setLastModified(lm);
    }
    IncidenceBaseWrapper::sbk_o_setDtStart("Incidence", funcName, gil, pyOverride, lm);
}

void IncidenceWrapper::setReadOnly(bool readonly)
{
    static const char *funcName = "setReadOnly";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_Incidence_TypeF(), gil, funcName, m_PyMethodCache[19], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::Incidence::setReadOnly(readonly);
    }
    IncidenceBaseWrapper::sbk_o_setAllDay("Incidence", funcName, gil, pyOverride, readonly);
}

void IncidenceWrapper::shiftTimes(const ::QTimeZone & oldZone, const ::QTimeZone & newZone)
{
    static const char *funcName = "shiftTimes";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_Incidence_TypeF(), gil, funcName, m_PyMethodCache[20], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::Incidence::shiftTimes(oldZone, newZone);
    }
    IncidenceBaseWrapper::sbk_o_shiftTimes("Incidence", funcName, gil, pyOverride, oldZone, newZone);
}

::QList<QDateTime> IncidenceWrapper::startDateTimesForDate(const ::QDate & date, const ::QTimeZone & timeZone) const
{
    static const char *funcName = "startDateTimesForDate";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_Incidence_TypeF(), gil, funcName, m_PyMethodCache[21], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::Incidence::startDateTimesForDate(date, timeZone);
    }
    return sbk_o_startDateTimesForDate("Incidence", funcName, gil, pyOverride, date, timeZone);
}

::QList<QDateTime> IncidenceWrapper::sbk_o_startDateTimesForDate([[maybe_unused]] const char *ownerClassName, [[maybe_unused]] const char *funcName, [[maybe_unused]] Shiboken::GilState &gil, [[maybe_unused]] const Shiboken::AutoDecRef &pyOverride, [[maybe_unused]] const ::QDate & date, [[maybe_unused]] const ::QTimeZone & timeZone)
{
#if !defined(PYPY_VERSION) && (!defined(Py_LIMITED_API) || Py_LIMITED_API >= 0x030C0000)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), &date),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]), &timeZone)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), &date),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]), &timeZone)
    ));
#endif

#if !defined(PYPY_VERSION) && (!defined(Py_LIMITED_API) || Py_LIMITED_API >= 0x030C0000)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return {};
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(SbkKCalendarCoreTypeConverters[SBK_KCalendarCore_QList_QDateTime_IDX], pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, "list", Py_TYPE(pyResult)->tp_name);
        return {};
    }
    ::QList<QDateTime> cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QList<QDateTime> IncidenceWrapper::startDateTimesForDateTime(const ::QDateTime & datetime) const
{
    static const char *funcName = "startDateTimesForDateTime";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_Incidence_TypeF(), gil, funcName, m_PyMethodCache[22], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::Incidence::startDateTimesForDateTime(datetime);
    }
    return sbk_o_startDateTimesForDateTime("Incidence", funcName, gil, pyOverride, datetime);
}

::QList<QDateTime> IncidenceWrapper::sbk_o_startDateTimesForDateTime([[maybe_unused]] const char *ownerClassName, [[maybe_unused]] const char *funcName, [[maybe_unused]] Shiboken::GilState &gil, [[maybe_unused]] const Shiboken::AutoDecRef &pyOverride, [[maybe_unused]] const ::QDateTime & datetime)
{
#if !defined(PYPY_VERSION) && (!defined(Py_LIMITED_API) || Py_LIMITED_API >= 0x030C0000)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), &datetime)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), &datetime)
    ));
#endif

#if !defined(PYPY_VERSION) && (!defined(Py_LIMITED_API) || Py_LIMITED_API >= 0x030C0000)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return {};
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(SbkKCalendarCoreTypeConverters[SBK_KCalendarCore_QList_QDateTime_IDX], pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, "list", Py_TYPE(pyResult)->tp_name);
        return {};
    }
    ::QList<QDateTime> cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool IncidenceWrapper::supportsGroupwareCommunication() const
{
    static const char *funcName = "supportsGroupwareCommunication";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_Incidence_TypeF(), gil, funcName, m_PyMethodCache[23], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("Incidence.supportsGroupwareCommunication");
        return false;
    }
    return sbk_o_supportsGroupwareCommunication("Incidence", funcName, gil, pyOverride);
}

bool IncidenceWrapper::sbk_o_supportsGroupwareCommunication([[maybe_unused]] const char *ownerClassName, [[maybe_unused]] const char *funcName, [[maybe_unused]] Shiboken::GilState &gil, [[maybe_unused]] const Shiboken::AutoDecRef &pyOverride)
{
#if defined(PYPY_VERSION)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION)
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::KCalendarCore::IncidenceBase::IncidenceType IncidenceWrapper::type() const
{
    static const char *funcName = "type";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_Incidence_TypeF(), gil, funcName, m_PyMethodCache[24], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("Incidence.type");
        return KCalendarCore::IncidenceBase::TypeEvent;
    }
    return IncidenceBaseWrapper::sbk_o_type("Incidence", funcName, gil, pyOverride);
}

::QByteArray IncidenceWrapper::typeStr() const
{
    static const char *funcName = "typeStr";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_Incidence_TypeF(), gil, funcName, m_PyMethodCache[25], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("Incidence.typeStr");
        return {};
    }
    return IncidenceBaseWrapper::sbk_o_typeStr("Incidence", funcName, gil, pyOverride);
}

void IncidenceWrapper::virtual_hook(::KCalendarCore::IncidenceBase::VirtualHook id, void * data)
{
    static const char *funcName = "virtual_hook";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_Incidence_TypeF(), gil, funcName, m_PyMethodCache[26], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("Incidence.virtual_hook");
        return;
    }
    IncidenceBaseWrapper::sbk_o_virtual_hook("Incidence", funcName, gil, pyOverride, id, data);
}

IncidenceWrapper::~IncidenceWrapper()
{
    auto *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this, Sbk_KCalendarCore_Incidence_TypeF());
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int Sbk_KCalendarCore_Incidence_Init(PyObject *, PyObject *, PyObject *)
{
    Shiboken::Errors::setInstantiateNonConstructible("Incidence");
    return -1;
}

static PyObject *Sbk_KCalendarCore_IncidenceFunc_addAttachment(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Incidence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Incidence::addAttachment(const KCalendarCore::Attachment&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Attachment_IDX]), (pyArg)))) {
        overloadId = 0; // Incidence::addAttachment(const KCalendarCore::Attachment&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "addAttachment", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::KCalendarCore::Attachment cppArg0_local;
        ::KCalendarCore::Attachment *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // Incidence::addAttachment(const KCalendarCore::Attachment&)
            cppSelf->addAttachment(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_IncidenceFunc_addConference(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Incidence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Incidence::addConference(const KCalendarCore::Conference&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Conference_IDX]), (pyArg)))) {
        overloadId = 0; // Incidence::addConference(const KCalendarCore::Conference&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "addConference", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::KCalendarCore::Conference cppArg0_local;
        ::KCalendarCore::Conference *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // Incidence::addConference(const KCalendarCore::Conference&)
            cppSelf->addConference(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_IncidenceFunc_altDescription(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Incidence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Incidence::altDescription()const->QString
        QString cppResult = const_cast<const ::KCalendarCore::Incidence *>(cppSelf)->altDescription();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_IncidenceFunc_attachments(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Incidence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "attachments", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: Incidence::attachments()const->QList<KCalendarCore::Attachment>
    // 1: Incidence::attachments(const QString&)const->QList<KCalendarCore::Attachment>
    if (numArgs == 0) {
        overloadId = 0; // attachments()const
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        overloadId = 1; // Incidence::attachments(const QString&)const->QList<KCalendarCore::Attachment>
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "attachments", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // attachments() const
        {

            // Incidence::attachments()const->QList<KCalendarCore::Attachment>
            QList<KCalendarCore::Attachment> cppResult = const_cast<const ::KCalendarCore::Incidence *>(cppSelf)->attachments();
            pyResult = Shiboken::Conversions::copyToPython(SbkKCalendarCoreTypeConverters[SBK_KCalendarCore_QList_KCalendarCore_Attachment_IDX], &cppResult);
            break;
        }
        case 1: // attachments(const QString &mime) const
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // Incidence::attachments(const QString&)const->QList<KCalendarCore::Attachment>
                QList<KCalendarCore::Attachment> cppResult = const_cast<const ::KCalendarCore::Incidence *>(cppSelf)->attachments(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(SbkKCalendarCoreTypeConverters[SBK_KCalendarCore_QList_KCalendarCore_Attachment_IDX], &cppResult);
            }
            break;
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_IncidenceFunc_categories(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Incidence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Incidence::categories()const->QStringList
        QStringList cppResult = const_cast<const ::KCalendarCore::Incidence *>(cppSelf)->categories();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_IncidenceFunc_categoriesStr(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Incidence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Incidence::categoriesStr()const->QString
        QString cppResult = const_cast<const ::KCalendarCore::Incidence *>(cppSelf)->categoriesStr();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_IncidenceFunc_clearAlarms(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Incidence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Incidence::clearAlarms()
        cppSelf->clearAlarms();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_IncidenceFunc_clearAttachments(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Incidence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Incidence::clearAttachments()
        cppSelf->clearAttachments();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_IncidenceFunc_clearConferences(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Incidence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Incidence::clearConferences()
        cppSelf->clearConferences();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_IncidenceFunc_clearRecurrence(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Incidence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Incidence::clearRecurrence()
        cppSelf->clearRecurrence();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_IncidenceFunc_clone(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Incidence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Incidence::clone()const->KCalendarCore::Incidence*
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("Incidence.clone");
            return {};
        }
        KCalendarCore::Incidence * cppResult = const_cast<const ::KCalendarCore::Incidence *>(cppSelf)->clone();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]), cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_IncidenceFunc_color(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Incidence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Incidence::color()const->QString
        QString cppResult = const_cast<const ::KCalendarCore::Incidence *>(cppSelf)->color();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_IncidenceFunc_conferences(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Incidence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Incidence::conferences()const->QList<KCalendarCore::Conference>
        QList<KCalendarCore::Conference> cppResult = const_cast<const ::KCalendarCore::Incidence *>(cppSelf)->conferences();
        pyResult = Shiboken::Conversions::copyToPython(SbkKCalendarCoreTypeConverters[SBK_KCalendarCore_QList_KCalendarCore_Conference_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_IncidenceFunc_created(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Incidence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Incidence::created()const->QDateTime
        QDateTime cppResult = const_cast<const ::KCalendarCore::Incidence *>(cppSelf)->created();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_IncidenceFunc_customStatus(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Incidence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Incidence::customStatus()const->QString
        QString cppResult = const_cast<const ::KCalendarCore::Incidence *>(cppSelf)->customStatus();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_IncidenceFunc_deleteAttachments(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Incidence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Incidence::deleteAttachments(const QString&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // Incidence::deleteAttachments(const QString&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "deleteAttachments", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Incidence::deleteAttachments(const QString&)
            cppSelf->deleteAttachments(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_IncidenceFunc_description(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Incidence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Incidence::description()const->QString
        QString cppResult = const_cast<const ::KCalendarCore::Incidence *>(cppSelf)->description();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_IncidenceFunc_descriptionIsRich(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Incidence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Incidence::descriptionIsRich()const->bool
        bool cppResult = const_cast<const ::KCalendarCore::Incidence *>(cppSelf)->descriptionIsRich();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_IncidenceFunc_deserialize(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Incidence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: IncidenceBase::deserialize(QDataStream&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), (pyArg)))) {
        overloadId = 0; // IncidenceBase::deserialize(QDataStream&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "deserialize", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDataStream *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // IncidenceBase::deserialize(QDataStream&)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::KCalendarCore::Incidence::deserialize(*cppArg0)
                : cppSelf->deserialize(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_IncidenceFunc_endDateForStart(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Incidence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Incidence::endDateForStart(const QDateTime&)const->QDateTime
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArg)))) {
        overloadId = 0; // Incidence::endDateForStart(const QDateTime&)const->QDateTime
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "endDateForStart", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDateTime cppArg0_local;
        ::QDateTime *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // Incidence::endDateForStart(const QDateTime&)const->QDateTime
            QDateTime cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::KCalendarCore::Incidence *>(cppSelf)->::KCalendarCore::Incidence::endDateForStart(*cppArg0)
                : const_cast<const ::KCalendarCore::Incidence *>(cppSelf)->endDateForStart(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_IncidenceFunc_equals(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Incidence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: IncidenceBase::equals(const KCalendarCore::IncidenceBase&)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]), (pyArg)))) {
        overloadId = 0; // IncidenceBase::equals(const KCalendarCore::IncidenceBase&)const->bool
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "equals", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::KCalendarCore::IncidenceBase *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // IncidenceBase::equals(const KCalendarCore::IncidenceBase&)const->bool
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::KCalendarCore::Incidence *>(cppSelf)->::KCalendarCore::Incidence::equals(*cppArg0)
                : const_cast<const ::KCalendarCore::Incidence *>(cppSelf)->equals(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_IncidenceFunc_geoLatitude(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Incidence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Incidence::geoLatitude()const->float
        float cppResult = const_cast<const ::KCalendarCore::Incidence *>(cppSelf)->geoLatitude();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_IncidenceFunc_geoLongitude(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Incidence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Incidence::geoLongitude()const->float
        float cppResult = const_cast<const ::KCalendarCore::Incidence *>(cppSelf)->geoLongitude();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_IncidenceFunc_hasAltDescription(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Incidence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Incidence::hasAltDescription()const->bool
        bool cppResult = const_cast<const ::KCalendarCore::Incidence *>(cppSelf)->hasAltDescription();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_IncidenceFunc_hasEnabledAlarms(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Incidence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Incidence::hasEnabledAlarms()const->bool
        bool cppResult = const_cast<const ::KCalendarCore::Incidence *>(cppSelf)->hasEnabledAlarms();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_IncidenceFunc_hasGeo(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Incidence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Incidence::hasGeo()const->bool
        bool cppResult = const_cast<const ::KCalendarCore::Incidence *>(cppSelf)->hasGeo();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_IncidenceFunc_hasRecurrenceId(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Incidence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Incidence::hasRecurrenceId()const->bool
        bool cppResult = const_cast<const ::KCalendarCore::Incidence *>(cppSelf)->hasRecurrenceId();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_IncidenceFunc_iconName(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Incidence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "iconName", errInfo, SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]);

    if (PyArg_ParseTuple(args, "|O:iconName", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: Incidence::iconName(const QDateTime&=)const->QLatin1String
    if (numArgs == 0) {
        overloadId = 0; // iconName(QDateTime)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArgs[0])))) {
        overloadId = 0; // Incidence::iconName(const QDateTime&=)const->QLatin1String
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "iconName", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]);

    // Call function/method
    {
        if (kwds != nullptr && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"recurrenceId", 0}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !((pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArgs[0])))))) {
                Py_XINCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "iconName", errInfo, SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QDateTime cppArg0_local{};
        ::QDateTime *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0]) {
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);
            }

        if (Shiboken::Errors::occurred() == nullptr) {
            // Incidence::iconName(const QDateTime&=)const->QLatin1String
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("Incidence.iconName");
                return {};
            }
            QLatin1String cppResult = const_cast<const ::KCalendarCore::Incidence *>(cppSelf)->iconName(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QLatin1String_IDX], &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_IncidenceFunc_instanceIdentifier(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Incidence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Incidence::instanceIdentifier()const->QString
        QString cppResult = const_cast<const ::KCalendarCore::Incidence *>(cppSelf)->instanceIdentifier();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_IncidenceFunc_localOnly(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Incidence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Incidence::localOnly()const->bool
        bool cppResult = const_cast<const ::KCalendarCore::Incidence *>(cppSelf)->localOnly();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_IncidenceFunc_location(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Incidence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Incidence::location()const->QString
        QString cppResult = const_cast<const ::KCalendarCore::Incidence *>(cppSelf)->location();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_IncidenceFunc_locationIsRich(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Incidence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Incidence::locationIsRich()const->bool
        bool cppResult = const_cast<const ::KCalendarCore::Incidence *>(cppSelf)->locationIsRich();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_IncidenceFunc_mimeTypes([[maybe_unused]] PyObject *self)
{
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // static Incidence::mimeTypes()->QStringList
        QStringList cppResult = ::KCalendarCore::Incidence::mimeTypes();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_IncidenceFunc_priority(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Incidence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Incidence::priority()const->int
        int cppResult = const_cast<const ::KCalendarCore::Incidence *>(cppSelf)->priority();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_IncidenceFunc_recreate(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Incidence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Incidence::recreate()
        cppSelf->recreate();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_IncidenceFunc_recurrence(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Incidence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Incidence::recurrence()const->KCalendarCore::Recurrence*
        KCalendarCore::Recurrence * cppResult = const_cast<const ::KCalendarCore::Incidence *>(cppSelf)->recurrence();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_IncidenceFunc_recurrenceId(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Incidence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // IncidenceBase::recurrenceId()const->QDateTime
        QDateTime cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::KCalendarCore::Incidence *>(cppSelf)->::KCalendarCore::Incidence::recurrenceId()
            : const_cast<const ::KCalendarCore::Incidence *>(cppSelf)->recurrenceId();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_IncidenceFunc_recurrenceType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Incidence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Incidence::recurrenceType()const->ushort
        ushort cppResult = const_cast<const ::KCalendarCore::Incidence *>(cppSelf)->recurrenceType();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<ushort>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_IncidenceFunc_recurrenceUpdated(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Incidence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: RecurrenceObserver::recurrenceUpdated(KCalendarCore::Recurrence*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_IDX]), (pyArg)))) {
        overloadId = 0; // RecurrenceObserver::recurrenceUpdated(KCalendarCore::Recurrence*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "recurrenceUpdated", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::KCalendarCore::Recurrence *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // RecurrenceObserver::recurrenceUpdated(KCalendarCore::Recurrence*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::KCalendarCore::Incidence::recurrenceUpdated(cppArg0)
                : cppSelf->recurrenceUpdated(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_IncidenceFunc_recurs(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Incidence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Incidence::recurs()const->bool
        bool cppResult = const_cast<const ::KCalendarCore::Incidence *>(cppSelf)->recurs();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_IncidenceFunc_recursAt(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Incidence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Incidence::recursAt(const QDateTime&)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArg)))) {
        overloadId = 0; // Incidence::recursAt(const QDateTime&)const->bool
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "recursAt", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDateTime cppArg0_local;
        ::QDateTime *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // Incidence::recursAt(const QDateTime&)const->bool
            bool cppResult = const_cast<const ::KCalendarCore::Incidence *>(cppSelf)->recursAt(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_IncidenceFunc_recursOn(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Incidence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "recursOn", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: Incidence::recursOn(const QDate&,const QTimeZone&)const->bool
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]), (pyArgs[1])))) {
        overloadId = 0; // Incidence::recursOn(const QDate&,const QTimeZone&)const->bool
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "recursOn", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QDate cppArg0_local;
        ::QDate *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QTimeZone cppArg1_local;
        ::QTimeZone *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // Incidence::recursOn(const QDate&,const QTimeZone&)const->bool
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::KCalendarCore::Incidence *>(cppSelf)->::KCalendarCore::Incidence::recursOn(*cppArg0, *cppArg1)
                : const_cast<const ::KCalendarCore::Incidence *>(cppSelf)->recursOn(*cppArg0, *cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_IncidenceFunc_relatedTo(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Incidence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "relatedTo", errInfo, SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]);

    if (PyArg_ParseTuple(args, "|O:relatedTo", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: Incidence::relatedTo(KCalendarCore::Incidence::RelType=)const->QString
    if (numArgs == 0) {
        overloadId = 0; // relatedTo(KCalendarCore::Incidence::RelType)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_RelType_IDX]))), (pyArgs[0])))) {
        overloadId = 0; // Incidence::relatedTo(KCalendarCore::Incidence::RelType=)const->QString
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "relatedTo", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]);

    // Call function/method
    {
        if (kwds != nullptr && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"relType", 0}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[0] != nullptr && !((pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_RelType_IDX]))), (pyArgs[0])))))) {
                Py_XINCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "relatedTo", errInfo, SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]);
            }
        }
        ::KCalendarCore::Incidence::RelType cppArg0(KCalendarCore::Incidence::RelType::RelTypeParent);
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Incidence::relatedTo(KCalendarCore::Incidence::RelType=)const->QString
            QString cppResult = const_cast<const ::KCalendarCore::Incidence *>(cppSelf)->relatedTo(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_IncidenceFunc_resources(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Incidence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Incidence::resources()const->QStringList
        QStringList cppResult = const_cast<const ::KCalendarCore::Incidence *>(cppSelf)->resources();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_IncidenceFunc_revision(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Incidence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Incidence::revision()const->int
        int cppResult = const_cast<const ::KCalendarCore::Incidence *>(cppSelf)->revision();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_IncidenceFunc_richDescription(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Incidence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Incidence::richDescription()const->QString
        QString cppResult = const_cast<const ::KCalendarCore::Incidence *>(cppSelf)->richDescription();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_IncidenceFunc_richLocation(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Incidence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Incidence::richLocation()const->QString
        QString cppResult = const_cast<const ::KCalendarCore::Incidence *>(cppSelf)->richLocation();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_IncidenceFunc_richSummary(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Incidence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Incidence::richSummary()const->QString
        QString cppResult = const_cast<const ::KCalendarCore::Incidence *>(cppSelf)->richSummary();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_IncidenceFunc_schedulingID(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Incidence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Incidence::schedulingID()const->QString
        QString cppResult = const_cast<const ::KCalendarCore::Incidence *>(cppSelf)->schedulingID();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_IncidenceFunc_secrecy(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Incidence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Incidence::secrecy()const->KCalendarCore::Incidence::Secrecy
        KCalendarCore::Incidence::Secrecy cppResult = const_cast<const ::KCalendarCore::Incidence *>(cppSelf)->secrecy();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_Secrecy_IDX]))), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_IncidenceFunc_serialize(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Incidence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: IncidenceBase::serialize(QDataStream&)const
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), (pyArg)))) {
        overloadId = 0; // IncidenceBase::serialize(QDataStream&)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "serialize", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDataStream *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // IncidenceBase::serialize(QDataStream&)const
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::KCalendarCore::Incidence *>(cppSelf)->::KCalendarCore::Incidence::serialize(*cppArg0)
                : const_cast<const ::KCalendarCore::Incidence *>(cppSelf)->serialize(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_IncidenceFunc_setAllDay(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Incidence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: IncidenceBase::setAllDay(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // IncidenceBase::setAllDay(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAllDay", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // IncidenceBase::setAllDay(bool)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::KCalendarCore::Incidence::setAllDay(cppArg0)
                : cppSelf->setAllDay(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_IncidenceFunc_setAltDescription(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Incidence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Incidence::setAltDescription(const QString&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // Incidence::setAltDescription(const QString&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAltDescription", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Incidence::setAltDescription(const QString&)
            cppSelf->setAltDescription(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_IncidenceFunc_setCategories(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Incidence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Incidence::setCategories(const QString&)
    // 1: Incidence::setCategories(const QStringList&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArg)))) {
        overloadId = 1; // Incidence::setCategories(const QStringList&)
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // Incidence::setCategories(const QString&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setCategories", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // setCategories(const QString &catStr)
        {
            ::QString cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // Incidence::setCategories(const QString&)
                cppSelf->setCategories(cppArg0);
            }
            break;
        }
        case 1: // setCategories(const QStringList &categories)
        {
            ::QStringList cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // Incidence::setCategories(const QStringList&)
                cppSelf->setCategories(cppArg0);
            }
            break;
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_IncidenceFunc_setColor(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Incidence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Incidence::setColor(const QString&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // Incidence::setColor(const QString&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setColor", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Incidence::setColor(const QString&)
            cppSelf->setColor(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_IncidenceFunc_setConferences(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Incidence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Incidence::setConferences(const QList<KCalendarCore::Conference>&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkKCalendarCoreTypeConverters[SBK_KCalendarCore_QList_KCalendarCore_Conference_IDX], (pyArg)))) {
        overloadId = 0; // Incidence::setConferences(const QList<KCalendarCore::Conference>&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setConferences", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]);

    // Call function/method
    {
        ::QList<KCalendarCore::Conference> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Incidence::setConferences(const QList<KCalendarCore::Conference>&)
            cppSelf->setConferences(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_IncidenceFunc_setCreated(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Incidence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Incidence::setCreated(const QDateTime&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArg)))) {
        overloadId = 0; // Incidence::setCreated(const QDateTime&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setCreated", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDateTime cppArg0_local;
        ::QDateTime *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // Incidence::setCreated(const QDateTime&)
            cppSelf->setCreated(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_IncidenceFunc_setCustomStatus(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Incidence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Incidence::setCustomStatus(const QString&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // Incidence::setCustomStatus(const QString&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setCustomStatus", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Incidence::setCustomStatus(const QString&)
            cppSelf->setCustomStatus(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_IncidenceFunc_setDescription(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Incidence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setDescription", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: Incidence::setDescription(const QString&)
    // 1: Incidence::setDescription(const QString&,bool)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setDescription(QString)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1])))) {
            overloadId = 1; // Incidence::setDescription(const QString&,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setDescription", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // setDescription(const QString &description)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // Incidence::setDescription(const QString&)
                cppSelf->setDescription(cppArg0);
            }
            break;
        }
        case 1: // setDescription(const QString &description, bool isRich)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            bool cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // Incidence::setDescription(const QString&,bool)
                cppSelf->setDescription(cppArg0, cppArg1);
            }
            break;
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_IncidenceFunc_setDtStart(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Incidence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: IncidenceBase::setDtStart(const QDateTime&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArg)))) {
        overloadId = 0; // IncidenceBase::setDtStart(const QDateTime&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDtStart", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDateTime cppArg0_local;
        ::QDateTime *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // IncidenceBase::setDtStart(const QDateTime&)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::KCalendarCore::Incidence::setDtStart(*cppArg0)
                : cppSelf->setDtStart(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_IncidenceFunc_setGeoLatitude(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Incidence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Incidence::setGeoLatitude(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // Incidence::setGeoLatitude(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setGeoLatitude", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Incidence::setGeoLatitude(float)
            cppSelf->setGeoLatitude(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_IncidenceFunc_setGeoLongitude(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Incidence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Incidence::setGeoLongitude(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // Incidence::setGeoLongitude(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setGeoLongitude", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Incidence::setGeoLongitude(float)
            cppSelf->setGeoLongitude(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_IncidenceFunc_setLastModified(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Incidence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: IncidenceBase::setLastModified(const QDateTime&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArg)))) {
        overloadId = 0; // IncidenceBase::setLastModified(const QDateTime&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLastModified", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDateTime cppArg0_local;
        ::QDateTime *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // IncidenceBase::setLastModified(const QDateTime&)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::KCalendarCore::Incidence::setLastModified(*cppArg0)
                : cppSelf->setLastModified(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_IncidenceFunc_setLocalOnly(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Incidence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Incidence::setLocalOnly(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // Incidence::setLocalOnly(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLocalOnly", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Incidence::setLocalOnly(bool)
            cppSelf->setLocalOnly(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_IncidenceFunc_setLocation(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Incidence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setLocation", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: Incidence::setLocation(const QString&)
    // 1: Incidence::setLocation(const QString&,bool)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setLocation(QString)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1])))) {
            overloadId = 1; // Incidence::setLocation(const QString&,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setLocation", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // setLocation(const QString &location)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // Incidence::setLocation(const QString&)
                cppSelf->setLocation(cppArg0);
            }
            break;
        }
        case 1: // setLocation(const QString &location, bool isRich)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            bool cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // Incidence::setLocation(const QString&,bool)
                cppSelf->setLocation(cppArg0, cppArg1);
            }
            break;
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_IncidenceFunc_setPriority(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Incidence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Incidence::setPriority(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // Incidence::setPriority(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPriority", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Incidence::setPriority(int)
            cppSelf->setPriority(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_IncidenceFunc_setReadOnly(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Incidence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: IncidenceBase::setReadOnly(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // IncidenceBase::setReadOnly(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setReadOnly", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // IncidenceBase::setReadOnly(bool)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::KCalendarCore::Incidence::setReadOnly(cppArg0)
                : cppSelf->setReadOnly(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_IncidenceFunc_setRecurrenceId(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Incidence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Incidence::setRecurrenceId(const QDateTime&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArg)))) {
        overloadId = 0; // Incidence::setRecurrenceId(const QDateTime&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRecurrenceId", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDateTime cppArg0_local;
        ::QDateTime *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // Incidence::setRecurrenceId(const QDateTime&)
            cppSelf->setRecurrenceId(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_IncidenceFunc_setRelatedTo(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Incidence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setRelatedTo", errInfo, SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]);

    if (PyArg_ParseTuple(args, "|OO:setRelatedTo", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: Incidence::setRelatedTo(const QString&,KCalendarCore::Incidence::RelType=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setRelatedTo(QString,KCalendarCore::Incidence::RelType)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_RelType_IDX]))), (pyArgs[1])))) {
            overloadId = 0; // Incidence::setRelatedTo(const QString&,KCalendarCore::Incidence::RelType=)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setRelatedTo", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]);

    // Call function/method
    {
        if (kwds != nullptr && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"relType", 1}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !((pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_RelType_IDX]))), (pyArgs[1])))))) {
                Py_XINCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "setRelatedTo", errInfo, SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]);
            }
        }
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::KCalendarCore::Incidence::RelType cppArg1(KCalendarCore::Incidence::RelType::RelTypeParent);
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Incidence::setRelatedTo(const QString&,KCalendarCore::Incidence::RelType=)
            cppSelf->setRelatedTo(cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_IncidenceFunc_setResources(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Incidence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Incidence::setResources(const QStringList&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArg)))) {
        overloadId = 0; // Incidence::setResources(const QStringList&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setResources", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]);

    // Call function/method
    {
        ::QStringList cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Incidence::setResources(const QStringList&)
            cppSelf->setResources(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_IncidenceFunc_setRevision(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Incidence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Incidence::setRevision(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // Incidence::setRevision(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRevision", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Incidence::setRevision(int)
            cppSelf->setRevision(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_IncidenceFunc_setSchedulingID(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Incidence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setSchedulingID", errInfo, SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]);

    if (PyArg_ParseTuple(args, "|OO:setSchedulingID", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: Incidence::setSchedulingID(const QString&,const QString&=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setSchedulingID(QString,QString)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            overloadId = 0; // Incidence::setSchedulingID(const QString&,const QString&=)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setSchedulingID", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]);

    // Call function/method
    {
        if (kwds != nullptr && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"uid", 1}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !((pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))))) {
                Py_XINCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "setSchedulingID", errInfo, SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]);
            }
        }
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1 = QString();
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Incidence::setSchedulingID(const QString&,const QString&=)
            cppSelf->setSchedulingID(cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_IncidenceFunc_setSecrecy(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Incidence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Incidence::setSecrecy(KCalendarCore::Incidence::Secrecy)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_Secrecy_IDX]))), (pyArg)))) {
        overloadId = 0; // Incidence::setSecrecy(KCalendarCore::Incidence::Secrecy)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSecrecy", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]);

    // Call function/method
    {
        ::KCalendarCore::Incidence::Secrecy cppArg0{KCalendarCore::Incidence::SecrecyPublic};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Incidence::setSecrecy(KCalendarCore::Incidence::Secrecy)
            cppSelf->setSecrecy(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_IncidenceFunc_setStatus(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Incidence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Incidence::setStatus(KCalendarCore::Incidence::Status)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_Status_IDX]))), (pyArg)))) {
        overloadId = 0; // Incidence::setStatus(KCalendarCore::Incidence::Status)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setStatus", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]);

    // Call function/method
    {
        ::KCalendarCore::Incidence::Status cppArg0{KCalendarCore::Incidence::StatusNone};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Incidence::setStatus(KCalendarCore::Incidence::Status)
            cppSelf->setStatus(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_IncidenceFunc_setSummary(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Incidence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setSummary", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: Incidence::setSummary(const QString&)
    // 1: Incidence::setSummary(const QString&,bool)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setSummary(QString)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1])))) {
            overloadId = 1; // Incidence::setSummary(const QString&,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setSummary", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // setSummary(const QString &summary)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // Incidence::setSummary(const QString&)
                cppSelf->setSummary(cppArg0);
            }
            break;
        }
        case 1: // setSummary(const QString &summary, bool isRich)
        {
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            bool cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // Incidence::setSummary(const QString&,bool)
                cppSelf->setSummary(cppArg0, cppArg1);
            }
            break;
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_IncidenceFunc_setThisAndFuture(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Incidence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Incidence::setThisAndFuture(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // Incidence::setThisAndFuture(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setThisAndFuture", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // Incidence::setThisAndFuture(bool)
            cppSelf->setThisAndFuture(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_IncidenceFunc_shiftTimes(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Incidence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "shiftTimes", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: IncidenceBase::shiftTimes(const QTimeZone&,const QTimeZone&)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]), (pyArgs[1])))) {
        overloadId = 0; // IncidenceBase::shiftTimes(const QTimeZone&,const QTimeZone&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "shiftTimes", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QTimeZone cppArg0_local;
        ::QTimeZone *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QTimeZone cppArg1_local;
        ::QTimeZone *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // IncidenceBase::shiftTimes(const QTimeZone&,const QTimeZone&)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::KCalendarCore::Incidence::shiftTimes(*cppArg0, *cppArg1)
                : cppSelf->shiftTimes(*cppArg0, *cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_IncidenceFunc_startDateTimesForDate(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Incidence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "startDateTimesForDate", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: Incidence::startDateTimesForDate(const QDate&,const QTimeZone&)const->QList<QDateTime>
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]), (pyArgs[1])))) {
        overloadId = 0; // Incidence::startDateTimesForDate(const QDate&,const QTimeZone&)const->QList<QDateTime>
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "startDateTimesForDate", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QDate cppArg0_local;
        ::QDate *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QTimeZone cppArg1_local;
        ::QTimeZone *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // Incidence::startDateTimesForDate(const QDate&,const QTimeZone&)const->QList<QDateTime>
            QList<QDateTime> cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::KCalendarCore::Incidence *>(cppSelf)->::KCalendarCore::Incidence::startDateTimesForDate(*cppArg0, *cppArg1)
                : const_cast<const ::KCalendarCore::Incidence *>(cppSelf)->startDateTimesForDate(*cppArg0, *cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(SbkKCalendarCoreTypeConverters[SBK_KCalendarCore_QList_QDateTime_IDX], &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_IncidenceFunc_startDateTimesForDateTime(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Incidence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: Incidence::startDateTimesForDateTime(const QDateTime&)const->QList<QDateTime>
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArg)))) {
        overloadId = 0; // Incidence::startDateTimesForDateTime(const QDateTime&)const->QList<QDateTime>
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "startDateTimesForDateTime", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDateTime cppArg0_local;
        ::QDateTime *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // Incidence::startDateTimesForDateTime(const QDateTime&)const->QList<QDateTime>
            QList<QDateTime> cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::KCalendarCore::Incidence *>(cppSelf)->::KCalendarCore::Incidence::startDateTimesForDateTime(*cppArg0)
                : const_cast<const ::KCalendarCore::Incidence *>(cppSelf)->startDateTimesForDateTime(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkKCalendarCoreTypeConverters[SBK_KCalendarCore_QList_QDateTime_IDX], &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_IncidenceFunc_status(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Incidence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Incidence::status()const->KCalendarCore::Incidence::Status
        KCalendarCore::Incidence::Status cppResult = const_cast<const ::KCalendarCore::Incidence *>(cppSelf)->status();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_Status_IDX]))), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_IncidenceFunc_summary(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Incidence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Incidence::summary()const->QString
        QString cppResult = const_cast<const ::KCalendarCore::Incidence *>(cppSelf)->summary();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_IncidenceFunc_summaryIsRich(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Incidence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Incidence::summaryIsRich()const->bool
        bool cppResult = const_cast<const ::KCalendarCore::Incidence *>(cppSelf)->summaryIsRich();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_IncidenceFunc_supportsGroupwareCommunication(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Incidence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Incidence::supportsGroupwareCommunication()const->bool
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("Incidence.supportsGroupwareCommunication");
            return {};
        }
        bool cppResult = const_cast<const ::KCalendarCore::Incidence *>(cppSelf)->supportsGroupwareCommunication();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_IncidenceFunc_thisAndFuture(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::Incidence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // Incidence::thisAndFuture()const->bool
        bool cppResult = const_cast<const ::KCalendarCore::Incidence *>(cppSelf)->thisAndFuture();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}


static const char *Sbk_KCalendarCore_Incidence_PropertyStrings[] = {
    "attachments:",
    "categories::",
    "conferences:",
    "created::",
    "description::",
    "geoLatitude::",
    "geoLongitude::",
    "hasGeo:",
    "location::",
    "priority::",
    "secrecy::",
    "status::",
    "summary::",
    nullptr // Sentinel
};

static const char *Sbk_KCalendarCore_Incidence_EnumFlagInfo[] = {
    "RelType:IntEnum",
    "Secrecy:IntEnum",
    "Status:IntEnum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_KCalendarCore_Incidence_methods[] = {
    {"addAttachment", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceFunc_addAttachment), METH_O, nullptr},
    {"addConference", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceFunc_addConference), METH_O, nullptr},
    {"altDescription", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceFunc_altDescription), METH_NOARGS, nullptr},
    {"attachments", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceFunc_attachments), METH_VARARGS, nullptr},
    {"categories", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceFunc_categories), METH_NOARGS, nullptr},
    {"categoriesStr", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceFunc_categoriesStr), METH_NOARGS, nullptr},
    {"clearAlarms", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceFunc_clearAlarms), METH_NOARGS, nullptr},
    {"clearAttachments", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceFunc_clearAttachments), METH_NOARGS, nullptr},
    {"clearConferences", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceFunc_clearConferences), METH_NOARGS, nullptr},
    {"clearRecurrence", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceFunc_clearRecurrence), METH_NOARGS, nullptr},
    {"clone", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceFunc_clone), METH_NOARGS, nullptr},
    {"color", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceFunc_color), METH_NOARGS, nullptr},
    {"conferences", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceFunc_conferences), METH_NOARGS, nullptr},
    {"created", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceFunc_created), METH_NOARGS, nullptr},
    {"customStatus", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceFunc_customStatus), METH_NOARGS, nullptr},
    {"deleteAttachments", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceFunc_deleteAttachments), METH_O, nullptr},
    {"description", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceFunc_description), METH_NOARGS, nullptr},
    {"descriptionIsRich", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceFunc_descriptionIsRich), METH_NOARGS, nullptr},
    {"deserialize", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceFunc_deserialize), METH_O, nullptr},
    {"endDateForStart", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceFunc_endDateForStart), METH_O, nullptr},
    {"equals", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceFunc_equals), METH_O, nullptr},
    {"geoLatitude", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceFunc_geoLatitude), METH_NOARGS, nullptr},
    {"geoLongitude", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceFunc_geoLongitude), METH_NOARGS, nullptr},
    {"hasAltDescription", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceFunc_hasAltDescription), METH_NOARGS, nullptr},
    {"hasEnabledAlarms", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceFunc_hasEnabledAlarms), METH_NOARGS, nullptr},
    {"hasGeo", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceFunc_hasGeo), METH_NOARGS, nullptr},
    {"hasRecurrenceId", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceFunc_hasRecurrenceId), METH_NOARGS, nullptr},
    {"iconName", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceFunc_iconName), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"instanceIdentifier", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceFunc_instanceIdentifier), METH_NOARGS, nullptr},
    {"localOnly", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceFunc_localOnly), METH_NOARGS, nullptr},
    {"location", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceFunc_location), METH_NOARGS, nullptr},
    {"locationIsRich", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceFunc_locationIsRich), METH_NOARGS, nullptr},
    {"mimeTypes", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceFunc_mimeTypes), METH_NOARGS|METH_STATIC, nullptr},
    {"priority", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceFunc_priority), METH_NOARGS, nullptr},
    {"recreate", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceFunc_recreate), METH_NOARGS, nullptr},
    {"recurrence", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceFunc_recurrence), METH_NOARGS, nullptr},
    {"recurrenceId", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceFunc_recurrenceId), METH_NOARGS, nullptr},
    {"recurrenceType", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceFunc_recurrenceType), METH_NOARGS, nullptr},
    {"recurrenceUpdated", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceFunc_recurrenceUpdated), METH_O, nullptr},
    {"recurs", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceFunc_recurs), METH_NOARGS, nullptr},
    {"recursAt", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceFunc_recursAt), METH_O, nullptr},
    {"recursOn", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceFunc_recursOn), METH_VARARGS, nullptr},
    {"relatedTo", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceFunc_relatedTo), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"resources", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceFunc_resources), METH_NOARGS, nullptr},
    {"revision", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceFunc_revision), METH_NOARGS, nullptr},
    {"richDescription", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceFunc_richDescription), METH_NOARGS, nullptr},
    {"richLocation", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceFunc_richLocation), METH_NOARGS, nullptr},
    {"richSummary", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceFunc_richSummary), METH_NOARGS, nullptr},
    {"schedulingID", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceFunc_schedulingID), METH_NOARGS, nullptr},
    {"secrecy", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceFunc_secrecy), METH_NOARGS, nullptr},
    {"serialize", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceFunc_serialize), METH_O, nullptr},
    {"setAllDay", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceFunc_setAllDay), METH_O, nullptr},
    {"setAltDescription", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceFunc_setAltDescription), METH_O, nullptr},
    {"setCategories", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceFunc_setCategories), METH_O, nullptr},
    {"setColor", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceFunc_setColor), METH_O, nullptr},
    {"setConferences", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceFunc_setConferences), METH_O, nullptr},
    {"setCreated", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceFunc_setCreated), METH_O, nullptr},
    {"setCustomStatus", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceFunc_setCustomStatus), METH_O, nullptr},
    {"setDescription", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceFunc_setDescription), METH_VARARGS, nullptr},
    {"setDtStart", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceFunc_setDtStart), METH_O, nullptr},
    {"setGeoLatitude", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceFunc_setGeoLatitude), METH_O, nullptr},
    {"setGeoLongitude", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceFunc_setGeoLongitude), METH_O, nullptr},
    {"setLastModified", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceFunc_setLastModified), METH_O, nullptr},
    {"setLocalOnly", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceFunc_setLocalOnly), METH_O, nullptr},
    {"setLocation", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceFunc_setLocation), METH_VARARGS, nullptr},
    {"setPriority", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceFunc_setPriority), METH_O, nullptr},
    {"setReadOnly", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceFunc_setReadOnly), METH_O, nullptr},
    {"setRecurrenceId", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceFunc_setRecurrenceId), METH_O, nullptr},
    {"setRelatedTo", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceFunc_setRelatedTo), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setResources", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceFunc_setResources), METH_O, nullptr},
    {"setRevision", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceFunc_setRevision), METH_O, nullptr},
    {"setSchedulingID", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceFunc_setSchedulingID), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setSecrecy", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceFunc_setSecrecy), METH_O, nullptr},
    {"setStatus", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceFunc_setStatus), METH_O, nullptr},
    {"setSummary", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceFunc_setSummary), METH_VARARGS, nullptr},
    {"setThisAndFuture", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceFunc_setThisAndFuture), METH_O, nullptr},
    {"shiftTimes", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceFunc_shiftTimes), METH_VARARGS, nullptr},
    {"startDateTimesForDate", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceFunc_startDateTimesForDate), METH_VARARGS, nullptr},
    {"startDateTimesForDateTime", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceFunc_startDateTimesForDateTime), METH_O, nullptr},
    {"status", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceFunc_status), METH_NOARGS, nullptr},
    {"summary", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceFunc_summary), METH_NOARGS, nullptr},
    {"summaryIsRich", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceFunc_summaryIsRich), METH_NOARGS, nullptr},
    {"supportsGroupwareCommunication", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceFunc_supportsGroupwareCommunication), METH_NOARGS, nullptr},
    {"thisAndFuture", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceFunc_thisAndFuture), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_KCalendarCore_Incidence_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::KCalendarCore::Incidence *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<IncidenceWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_KCalendarCore_Incidence_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_KCalendarCore_Incidence_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
int *
Sbk_KCalendarCore_Incidence_mi_init(const void *cptr)
{
    static int mi_offsets[] = {-2, 0, 0, 0, 0, 0, 0};
    if (mi_offsets[0] == -2) {
        const auto *class_ptr = reinterpret_cast<const KCalendarCore::Incidence *>(cptr);
        const auto base = reinterpret_cast<uintptr_t>(class_ptr);
        int *p = mi_offsets;
        *p++ = int(reinterpret_cast<uintptr_t>(static_cast<const KCalendarCore::IncidenceBase *>(class_ptr)) - base);
        *p++ = int(reinterpret_cast<uintptr_t>(static_cast<const KCalendarCore::IncidenceBase *>(static_cast<const KCalendarCore::Incidence *>(static_cast<const void *>(class_ptr)))) - base);
        *p++ = int(reinterpret_cast<uintptr_t>(static_cast<const KCalendarCore::Recurrence::RecurrenceObserver *>(class_ptr)) - base);
        *p++ = int(reinterpret_cast<uintptr_t>(static_cast<const KCalendarCore::Recurrence::RecurrenceObserver *>(static_cast<const KCalendarCore::Incidence *>(static_cast<const void *>(class_ptr)))) - base);
        *p++ = int(reinterpret_cast<uintptr_t>(static_cast<const KCalendarCore::CustomProperties *>(class_ptr)) - base);
        *p++ = int(reinterpret_cast<uintptr_t>(static_cast<const KCalendarCore::CustomProperties *>(static_cast<const KCalendarCore::IncidenceBase *>(static_cast<const void *>(class_ptr)))) - base);
        std::sort(mi_offsets, p);
        auto *end = std::unique(mi_offsets, p);
        *end++ = -1;
        if (mi_offsets[0] == 0)
            std::memmove(&mi_offsets[0], &mi_offsets[1], (end - mi_offsets  - 1) * sizeof(int));
    }
    return mi_offsets;
}
static void * Sbk_KCalendarCore_IncidenceSpecialCastFunction(void *obj, PyTypeObject *desiredType)
{
    auto me = reinterpret_cast< ::KCalendarCore::Incidence *>(obj);
    if (desiredType == Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]))
        return static_cast< ::KCalendarCore::IncidenceBase *>(me);
    else if (desiredType == Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_CustomProperties_IDX]))
        return static_cast< ::KCalendarCore::CustomProperties *>(me);
    else if (desiredType == Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_RecurrenceObserver_IDX]))
        return static_cast< ::KCalendarCore::Recurrence::RecurrenceObserver *>(me);
    return me;
}



// Class Definition -----------------------------------------------
extern "C" {

static PyType_Slot Sbk_KCalendarCore_Incidence_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_KCalendarCore_Incidence_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_KCalendarCore_Incidence_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_KCalendarCore_Incidence_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_KCalendarCore_Incidence_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_KCalendarCore_Incidence_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkDummyNew /* PYSIDE-595: Prevent replacement of "0" with base->tp_new. */)},
    {0, nullptr}
};
static PyType_Spec Sbk_KCalendarCore_Incidence_spec = {
    "1:KCalendarCore.KCalendarCore.Incidence",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_KCalendarCore_Incidence_slots
};

} //extern "C"

static void *Sbk_KCalendarCore_Incidence_typeDiscovery([[maybe_unused]] void *cptr, [[maybe_unused]] PyTypeObject *instanceType)
{
    if (instanceType == Shiboken::SbkType< ::KCalendarCore::CustomProperties >())
        return dynamic_cast< ::KCalendarCore::Incidence *>(reinterpret_cast< ::KCalendarCore::CustomProperties *>(cptr));
    if (instanceType == Shiboken::SbkType< ::KCalendarCore::Recurrence::RecurrenceObserver >())
        return dynamic_cast< ::KCalendarCore::Incidence *>(reinterpret_cast< ::KCalendarCore::Recurrence::RecurrenceObserver *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_KCalendarCore_Incidence_Status(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::KCalendarCore::Incidence::Status>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::KCalendarCore::Incidence::Status *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_KCalendarCore_Incidence_Status_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_Status_IDX])))
        return Enum_PythonToCpp_KCalendarCore_Incidence_Status;
    return {};
}

static PyObject *KCalendarCore_Incidence_Status_CppToPython_Enum(PyTypeObject *pyType, const void *cppIn)
{
    using IntType = std::underlying_type_t<::KCalendarCore::Incidence::Status>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::KCalendarCore::Incidence::Status *>(cppIn));
    return Shiboken::Enum::newItem(pyType, castCppIn);

}

static void Enum_PythonToCpp_KCalendarCore_Incidence_Secrecy(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::KCalendarCore::Incidence::Secrecy>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::KCalendarCore::Incidence::Secrecy *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_KCalendarCore_Incidence_Secrecy_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_Secrecy_IDX])))
        return Enum_PythonToCpp_KCalendarCore_Incidence_Secrecy;
    return {};
}

static PyObject *KCalendarCore_Incidence_Secrecy_CppToPython_Enum(PyTypeObject *pyType, const void *cppIn)
{
    using IntType = std::underlying_type_t<::KCalendarCore::Incidence::Secrecy>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::KCalendarCore::Incidence::Secrecy *>(cppIn));
    return Shiboken::Enum::newItem(pyType, castCppIn);

}

static void Enum_PythonToCpp_KCalendarCore_Incidence_RelType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::KCalendarCore::Incidence::RelType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::KCalendarCore::Incidence::RelType *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_KCalendarCore_Incidence_RelType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_RelType_IDX])))
        return Enum_PythonToCpp_KCalendarCore_Incidence_RelType;
    return {};
}

static PyObject *KCalendarCore_Incidence_RelType_CppToPython_Enum(PyTypeObject *pyType, const void *cppIn)
{
    using IntType = std::underlying_type_t<::KCalendarCore::Incidence::RelType>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::KCalendarCore::Incidence::RelType *>(cppIn));
    return Shiboken::Enum::newItem(pyType, castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void Incidence_PythonToCpp_Incidence_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_KCalendarCore_Incidence_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_Incidence_PythonToCpp_Incidence_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_KCalendarCore_Incidence_TypeF()))
        return Incidence_PythonToCpp_Incidence_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *Incidence_PTR_CppToPython_Incidence(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn, Sbk_KCalendarCore_Incidence_TypeF()));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::KCalendarCore::Incidence *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_KCalendarCore_Incidence_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *KCalendarCore_Incidence_SignatureStrings[] = {
    "KCalendarCore.KCalendarCore.Incidence.addAttachment(self,attachment:typing.Union[KCalendarCore.KCalendarCore.Attachment, PySide6.QtCore.QByteArray, QString])",
    "KCalendarCore.KCalendarCore.Incidence.addConference(self,conference:KCalendarCore.KCalendarCore.Conference)",
    "KCalendarCore.KCalendarCore.Incidence.altDescription(self)->QString",
    "1:KCalendarCore.KCalendarCore.Incidence.attachments(self)->QList[KCalendarCore.KCalendarCore.Attachment]",
    "0:KCalendarCore.KCalendarCore.Incidence.attachments(self,mime:QString)->QList[KCalendarCore.KCalendarCore.Attachment]",
    "KCalendarCore.KCalendarCore.Incidence.categories(self)->QStringList",
    "KCalendarCore.KCalendarCore.Incidence.categoriesStr(self)->QString",
    "KCalendarCore.KCalendarCore.Incidence.clearAlarms(self)",
    "KCalendarCore.KCalendarCore.Incidence.clearAttachments(self)",
    "KCalendarCore.KCalendarCore.Incidence.clearConferences(self)",
    "KCalendarCore.KCalendarCore.Incidence.clearRecurrence(self)",
    "KCalendarCore.KCalendarCore.Incidence.clone(self)->KCalendarCore.KCalendarCore.Incidence",
    "KCalendarCore.KCalendarCore.Incidence.color(self)->QString",
    "KCalendarCore.KCalendarCore.Incidence.conferences(self)->QList[KCalendarCore.KCalendarCore.Conference]",
    "KCalendarCore.KCalendarCore.Incidence.created(self)->PySide6.QtCore.QDateTime",
    "KCalendarCore.KCalendarCore.Incidence.customStatus(self)->QString",
    "KCalendarCore.KCalendarCore.Incidence.deleteAttachments(self,mime:QString)",
    "KCalendarCore.KCalendarCore.Incidence.description(self)->QString",
    "KCalendarCore.KCalendarCore.Incidence.descriptionIsRich(self)->bool",
    "KCalendarCore.KCalendarCore.Incidence.deserialize(self,in:PySide6.QtCore.QDataStream)",
    "KCalendarCore.KCalendarCore.Incidence.endDateForStart(self,startDt:PySide6.QtCore.QDateTime)->PySide6.QtCore.QDateTime",
    "KCalendarCore.KCalendarCore.Incidence.equals(self,incidence:KCalendarCore.KCalendarCore.IncidenceBase)->bool",
    "KCalendarCore.KCalendarCore.Incidence.geoLatitude(self)->float",
    "KCalendarCore.KCalendarCore.Incidence.geoLongitude(self)->float",
    "KCalendarCore.KCalendarCore.Incidence.hasAltDescription(self)->bool",
    "KCalendarCore.KCalendarCore.Incidence.hasEnabledAlarms(self)->bool",
    "KCalendarCore.KCalendarCore.Incidence.hasGeo(self)->bool",
    "KCalendarCore.KCalendarCore.Incidence.hasRecurrenceId(self)->bool",
    "KCalendarCore.KCalendarCore.Incidence.iconName(self,recurrenceId:PySide6.QtCore.QDateTime={})->QLatin1String",
    "KCalendarCore.KCalendarCore.Incidence.instanceIdentifier(self)->QString",
    "KCalendarCore.KCalendarCore.Incidence.localOnly(self)->bool",
    "KCalendarCore.KCalendarCore.Incidence.location(self)->QString",
    "KCalendarCore.KCalendarCore.Incidence.locationIsRich(self)->bool",
    "KCalendarCore.KCalendarCore.Incidence.mimeTypes()->QStringList",
    "KCalendarCore.KCalendarCore.Incidence.priority(self)->int",
    "KCalendarCore.KCalendarCore.Incidence.recreate(self)",
    "KCalendarCore.KCalendarCore.Incidence.recurrence(self)->KCalendarCore.KCalendarCore.Recurrence",
    "KCalendarCore.KCalendarCore.Incidence.recurrenceId(self)->PySide6.QtCore.QDateTime",
    "KCalendarCore.KCalendarCore.Incidence.recurrenceType(self)->ushort",
    "KCalendarCore.KCalendarCore.Incidence.recurrenceUpdated(self,recurrence:KCalendarCore.KCalendarCore.Recurrence)",
    "KCalendarCore.KCalendarCore.Incidence.recurs(self)->bool",
    "KCalendarCore.KCalendarCore.Incidence.recursAt(self,dt:PySide6.QtCore.QDateTime)->bool",
    "KCalendarCore.KCalendarCore.Incidence.recursOn(self,date:PySide6.QtCore.QDate,timeZone:typing.Union[PySide6.QtCore.QTimeZone, PySide6.QtCore.QTimeZone.Initialization])->bool",
    "KCalendarCore.KCalendarCore.Incidence.relatedTo(self,relType:KCalendarCore.KCalendarCore.Incidence.RelType=KCalendarCore.Incidence.RelType.RelTypeParent)->QString",
    "KCalendarCore.KCalendarCore.Incidence.resources(self)->QStringList",
    "KCalendarCore.KCalendarCore.Incidence.revision(self)->int",
    "KCalendarCore.KCalendarCore.Incidence.richDescription(self)->QString",
    "KCalendarCore.KCalendarCore.Incidence.richLocation(self)->QString",
    "KCalendarCore.KCalendarCore.Incidence.richSummary(self)->QString",
    "KCalendarCore.KCalendarCore.Incidence.schedulingID(self)->QString",
    "KCalendarCore.KCalendarCore.Incidence.secrecy(self)->KCalendarCore.KCalendarCore.Incidence.Secrecy",
    "KCalendarCore.KCalendarCore.Incidence.serialize(self,out:PySide6.QtCore.QDataStream)",
    "KCalendarCore.KCalendarCore.Incidence.setAllDay(self,allDay:bool)",
    "KCalendarCore.KCalendarCore.Incidence.setAltDescription(self,altdescription:QString)",
    "1:KCalendarCore.KCalendarCore.Incidence.setCategories(self,catStr:QString)",
    "0:KCalendarCore.KCalendarCore.Incidence.setCategories(self,categories:QStringList)",
    "KCalendarCore.KCalendarCore.Incidence.setColor(self,colorName:QString)",
    "KCalendarCore.KCalendarCore.Incidence.setConferences(self,conferences:QList[KCalendarCore.KCalendarCore.Conference])",
    "KCalendarCore.KCalendarCore.Incidence.setCreated(self,dt:PySide6.QtCore.QDateTime)",
    "KCalendarCore.KCalendarCore.Incidence.setCustomStatus(self,status:QString)",
    "1:KCalendarCore.KCalendarCore.Incidence.setDescription(self,description:QString)",
    "0:KCalendarCore.KCalendarCore.Incidence.setDescription(self,description:QString,isRich:bool)",
    "KCalendarCore.KCalendarCore.Incidence.setDtStart(self,dt:PySide6.QtCore.QDateTime)",
    "KCalendarCore.KCalendarCore.Incidence.setGeoLatitude(self,geolatitude:float)",
    "KCalendarCore.KCalendarCore.Incidence.setGeoLongitude(self,geolongitude:float)",
    "KCalendarCore.KCalendarCore.Incidence.setLastModified(self,lm:PySide6.QtCore.QDateTime)",
    "KCalendarCore.KCalendarCore.Incidence.setLocalOnly(self,localonly:bool)",
    "1:KCalendarCore.KCalendarCore.Incidence.setLocation(self,location:QString)",
    "0:KCalendarCore.KCalendarCore.Incidence.setLocation(self,location:QString,isRich:bool)",
    "KCalendarCore.KCalendarCore.Incidence.setPriority(self,priority:int)",
    "KCalendarCore.KCalendarCore.Incidence.setReadOnly(self,readonly:bool)",
    "KCalendarCore.KCalendarCore.Incidence.setRecurrenceId(self,recurrenceId:PySide6.QtCore.QDateTime)",
    "KCalendarCore.KCalendarCore.Incidence.setRelatedTo(self,uid:QString,relType:KCalendarCore.KCalendarCore.Incidence.RelType=KCalendarCore.Incidence.RelType.RelTypeParent)",
    "KCalendarCore.KCalendarCore.Incidence.setResources(self,resources:QStringList)",
    "KCalendarCore.KCalendarCore.Incidence.setRevision(self,rev:int)",
    "KCalendarCore.KCalendarCore.Incidence.setSchedulingID(self,sid:QString,uid:QString=QString())",
    "KCalendarCore.KCalendarCore.Incidence.setSecrecy(self,secrecy:KCalendarCore.KCalendarCore.Incidence.Secrecy)",
    "KCalendarCore.KCalendarCore.Incidence.setStatus(self,status:KCalendarCore.KCalendarCore.Incidence.Status)",
    "1:KCalendarCore.KCalendarCore.Incidence.setSummary(self,summary:QString)",
    "0:KCalendarCore.KCalendarCore.Incidence.setSummary(self,summary:QString,isRich:bool)",
    "KCalendarCore.KCalendarCore.Incidence.setThisAndFuture(self,thisAndFuture:bool)",
    "KCalendarCore.KCalendarCore.Incidence.shiftTimes(self,oldZone:typing.Union[PySide6.QtCore.QTimeZone, PySide6.QtCore.QTimeZone.Initialization],newZone:typing.Union[PySide6.QtCore.QTimeZone, PySide6.QtCore.QTimeZone.Initialization])",
    "KCalendarCore.KCalendarCore.Incidence.startDateTimesForDate(self,date:PySide6.QtCore.QDate,timeZone:typing.Union[PySide6.QtCore.QTimeZone, PySide6.QtCore.QTimeZone.Initialization])->QList[PySide6.QtCore.QDateTime]",
    "KCalendarCore.KCalendarCore.Incidence.startDateTimesForDateTime(self,datetime:PySide6.QtCore.QDateTime)->QList[PySide6.QtCore.QDateTime]",
    "KCalendarCore.KCalendarCore.Incidence.status(self)->KCalendarCore.KCalendarCore.Incidence.Status",
    "KCalendarCore.KCalendarCore.Incidence.summary(self)->QString",
    "KCalendarCore.KCalendarCore.Incidence.summaryIsRich(self)->bool",
    "KCalendarCore.KCalendarCore.Incidence.supportsGroupwareCommunication(self)->bool",
    "KCalendarCore.KCalendarCore.Incidence.thisAndFuture(self)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t KCalendarCore_Incidence_SignatureByteSize = 1092;
static constexpr uint8_t KCalendarCore_Incidence_SignatureBytes[1092] = {
    0x78, 0xda, 0xc5, 0x58, 0x4d, 0x6f, 0xe3, 0x36, 0x10, 0xbd, 0xe7, 0x57, 0xec, 0x71, 0x03, 0xa8,
    0x46, 0xf6, 0xd2, 0x83, 0x80, 0x14, 0xf0, 0xda, 0x4d, 0x60, 0xc4, 0xed, 0x26, 0xb6, 0xf7, 0xd2,
    0x22, 0x07, 0xae, 0x48, 0xc7, 0x04, 0x28, 0xd2, 0x25, 0xa9, 0x5d, 0xb8, 0x45, 0xff, 0x7b, 0x87,
    0x32, 0x25, 0x51, 0x72, 0xa2, 0x72, 0x68, 0x6f, 0x7b, 0x92, 0x28, 0x69, 0xde, 0x90, 0xf3, 0xf9,
    0x46, 0x0f, 0x33, 0x22, 0x98, 0xa4, 0x44, 0xcf, 0x94, 0x66, 0x93, 0x87, 0xde, 0x6a, 0x21, 0x0b,
    0x4e, 0x99, 0x2c, 0xd8, 0x84, 0x50, 0x3a, 0xb5, 0x96, 0x14, 0xbb, 0x92, 0x49, 0xfb, 0xde, 0x30,
    0xb1, 0xcd, 0x48, 0xbb, 0xce, 0xed, 0x61, 0xcf, 0xe5, 0xcb, 0xe4, 0xb3, 0xe4, 0x4a, 0xfe, 0xfe,
    0x30, 0x02, 0xd8, 0x61, 0x64, 0xef, 0x1e, 0x0f, 0x6b, 0x00, 0xff, 0x71, 0xf2, 0x64, 0xeb, 0x57,
    0x4f, 0x1f, 0x0f, 0x96, 0x4d, 0xb5, 0x26, 0x87, 0xec, 0xdd, 0xd3, 0xda, 0x6a, 0x00, 0x7c, 0xbe,
    0xbe, 0x7a, 0x88, 0xdd, 0xdd, 0x4c, 0xc9, 0x2d, 0xd3, 0x6e, 0x75, 0xdc, 0x5d, 0xd1, 0xae, 0xf3,
    0x31, 0x8c, 0x4e, 0x2c, 0x5a, 0x97, 0xb0, 0x73, 0x66, 0x0a, 0xcd, 0xf7, 0x16, 0x4e, 0x5b, 0x2b,
    0xbb, 0xfe, 0xe1, 0x27, 0xbf, 0xe3, 0xab, 0x0f, 0x79, 0x24, 0x4a, 0x6b, 0x08, 0xd3, 0x42, 0x2c,
    0xb9, 0xb1, 0x91, 0xd6, 0x7b, 0xbe, 0xba, 0x49, 0x54, 0x94, 0x95, 0xbc, 0x64, 0xb9, 0xdf, 0x2e,
    0x5a, 0x6b, 0x9c, 0xce, 0x82, 0x58, 0xf6, 0xa2, 0x34, 0x67, 0x66, 0x60, 0x1e, 0xa7, 0x0b, 0x8d,
    0x01, 0xa2, 0x43, 0x2b, 0x47, 0x42, 0x08, 0x46, 0xf4, 0x54, 0x10, 0x5d, 0xfa, 0x7d, 0xa0, 0xe4,
    0x86, 0x0e, 0xc2, 0x08, 0x77, 0x51, 0x95, 0x20, 0xbc, 0x62, 0x45, 0xa5, 0xbb, 0x48, 0x8e, 0x97,
    0x55, 0x92, 0x35, 0x86, 0x8a, 0x12, 0x89, 0x05, 0x56, 0x42, 0xa5, 0x7a, 0x60, 0x68, 0x87, 0x98,
    0x78, 0xeb, 0x8c, 0x17, 0x1d, 0x6f, 0x9a, 0x41, 0xb4, 0xd0, 0x46, 0xc5, 0xb0, 0xb0, 0xcc, 0xe1,
    0xe5, 0x06, 0xa2, 0x3e, 0x16, 0xad, 0x32, 0x56, 0x95, 0x6b, 0x4b, 0x6c, 0x65, 0xd2, 0x8e, 0x4d,
    0x99, 0x60, 0x50, 0xcb, 0x46, 0x33, 0x2f, 0x1a, 0xea, 0xcd, 0x52, 0x83, 0x06, 0x58, 0x98, 0x15,
    0x2f, 0x76, 0x0d, 0xcc, 0x17, 0xa5, 0x44, 0x3c, 0x06, 0xd3, 0x9c, 0x08, 0xfe, 0xa7, 0x2f, 0xae,
    0x5c, 0xe6, 0xaf, 0x18, 0x99, 0xc0, 0xc6, 0x18, 0x29, 0x63, 0x8f, 0x06, 0xcf, 0x9c, 0x67, 0xee,
    0x94, 0x06, 0x5b, 0x6b, 0xdf, 0x54, 0x8c, 0xbb, 0x9d, 0xdb, 0xfc, 0x2d, 0x1f, 0x9e, 0xef, 0x5e,
    0xf6, 0x47, 0x45, 0x84, 0x69, 0xce, 0xe1, 0x9f, 0xc6, 0x15, 0xd3, 0x8f, 0xc4, 0x30, 0x9c, 0xe5,
    0x5e, 0x98, 0x5a, 0x12, 0xcb, 0x6d, 0x45, 0xdb, 0xd4, 0xdc, 0x0a, 0x45, 0x2c, 0x42, 0x5c, 0xc9,
    0x97, 0x64, 0xf9, 0x1d, 0x31, 0xd3, 0x57, 0xdb, 0x15, 0xe2, 0x08, 0x80, 0xf1, 0xb3, 0x24, 0x5f,
    0x04, 0xa3, 0x61, 0x29, 0xc5, 0x42, 0xdc, 0x33, 0x95, 0x26, 0xd8, 0x55, 0xc3, 0x05, 0x4d, 0x40,
    0xe0, 0x50, 0x82, 0x7e, 0x25, 0xa5, 0x8f, 0x5b, 0x1d, 0x80, 0xbd, 0x19, 0x62, 0xb7, 0x7f, 0xfd,
    0x5d, 0xd7, 0x29, 0xf0, 0x9b, 0xfc, 0x80, 0xca, 0x35, 0x2e, 0x21, 0x7c, 0x6b, 0x70, 0x48, 0x7a,
    0xbe, 0xe5, 0x2c, 0xb1, 0x6c, 0x0a, 0x55, 0x10, 0xf1, 0x49, 0x8a, 0x43, 0xc2, 0x81, 0x9d, 0x6c,
    0x7a, 0xb5, 0x68, 0xa4, 0x93, 0x4b, 0x85, 0xab, 0x71, 0x9b, 0xc3, 0x1e, 0xea, 0x7d, 0x52, 0xd7,
    0xdf, 0x6b, 0x0e, 0x3d, 0xdf, 0xb6, 0x07, 0xe7, 0x32, 0x56, 0x12, 0x5c, 0x5b, 0x77, 0x01, 0x54,
    0xcf, 0xd4, 0x83, 0x56, 0x3b, 0xde, 0x38, 0xbb, 0x50, 0x44, 0xc3, 0x2f, 0x2e, 0xd5, 0x9c, 0x3a,
    0x48, 0x67, 0xe5, 0x06, 0xb4, 0x32, 0x3b, 0xa5, 0x2d, 0x1a, 0xe2, 0xf3, 0x9e, 0xb6, 0x7d, 0x33,
    0xc8, 0x8d, 0x3c, 0xce, 0x08, 0x28, 0x23, 0xa7, 0x94, 0x8d, 0xa3, 0xe0, 0xd4, 0x77, 0x06, 0x3a,
    0xda, 0x14, 0xd0, 0xb0, 0x9f, 0xa4, 0x87, 0x05, 0x8c, 0x57, 0x81, 0x33, 0x0b, 0xc8, 0xbf, 0x01,
    0xa7, 0xea, 0x4f, 0x37, 0xc3, 0x4f, 0x37, 0xfe, 0xab, 0xd3, 0x79, 0xa6, 0x79, 0x03, 0xaa, 0xb9,
    0xad, 0xbb, 0x67, 0x9d, 0x5a, 0xcf, 0xd8, 0xdd, 0x0a, 0xe7, 0xa3, 0x8d, 0x6a, 0xbc, 0x24, 0x9c,
    0xe3, 0x23, 0xc9, 0xff, 0xea, 0xf8, 0xf5, 0xed, 0xbf, 0xbc, 0x6f, 0xae, 0x8f, 0x04, 0x1c, 0x6b,
    0xd1, 0x45, 0x43, 0x33, 0xa3, 0x2a, 0x5d, 0x9c, 0xc3, 0xf6, 0x35, 0xfb, 0xca, 0x4d, 0x50, 0xb5,
    0x10, 0x79, 0x0f, 0x75, 0x6a, 0x7e, 0x2e, 0x49, 0x72, 0x20, 0xcb, 0xb3, 0x0a, 0xa7, 0x43, 0x58,
    0x57, 0x65, 0x49, 0xf4, 0x21, 0x0d, 0xc0, 0x14, 0x3b, 0x46, 0x2b, 0x01, 0x02, 0x8b, 0x79, 0x22,
    0x82, 0xab, 0x80, 0xc5, 0x01, 0x35, 0x02, 0x4c, 0xd6, 0x47, 0xa1, 0x68, 0x15, 0x3d, 0x1a, 0xa8,
    0x2a, 0x7b, 0x01, 0x1e, 0x68, 0x98, 0x9d, 0x0a, 0x31, 0x27, 0x07, 0xff, 0x5b, 0xa1, 0xbe, 0xcf,
    0x5d, 0x8a, 0xa0, 0x10, 0x4e, 0x68, 0x0e, 0x20, 0xd9, 0x80, 0xfd, 0x76, 0xcc, 0x3b, 0x76, 0x46,
    0x07, 0xd8, 0x59, 0x7f, 0x92, 0xcd, 0x20, 0x44, 0x00, 0xa5, 0x83, 0xba, 0x39, 0x0b, 0xca, 0xaf,
    0xf3, 0x20, 0x5f, 0x10, 0x47, 0x9e, 0xb5, 0x73, 0x59, 0x56, 0x8f, 0x68, 0x8e, 0xe6, 0x60, 0xc7,
    0x8b, 0x1a, 0xa6, 0x3f, 0xa3, 0x05, 0x7f, 0x4e, 0x60, 0x67, 0x98, 0x69, 0x0d, 0xa3, 0x34, 0x98,
    0xd8, 0x46, 0x2b, 0x3b, 0x02, 0x72, 0x38, 0xb6, 0xb9, 0x59, 0x02, 0xee, 0x93, 0xfc, 0x7e, 0x12,
    0x4b, 0xaf, 0x06, 0xd2, 0xcd, 0x65, 0x01, 0x33, 0x5e, 0xb3, 0x2e, 0x6c, 0xe8, 0xcf, 0x6d, 0x30,
    0x3f, 0x5d, 0xc6, 0x96, 0xf7, 0x83, 0xb1, 0x25, 0x83, 0x41, 0x44, 0xf8, 0x07, 0x79, 0x3d, 0x80,
    0x20, 0xc1, 0x7a, 0x43, 0x4c, 0x8d, 0xd6, 0x3c, 0x41, 0xc3, 0x2d, 0x89, 0xb1, 0xbf, 0x28, 0xea,
    0xe8, 0xb5, 0x8f, 0x1f, 0x51, 0x5e, 0xe2, 0xcc, 0xcb, 0x1e, 0xe9, 0xce, 0x6a, 0x0e, 0xae, 0x60,
    0xe9, 0xdd, 0x81, 0x08, 0x9e, 0x5e, 0x27, 0xc9, 0x1a, 0x4a, 0x9d, 0x14, 0x36, 0xe3, 0x50, 0x89,
    0x01, 0xf3, 0x18, 0x92, 0xec, 0xac, 0xa1, 0xdc, 0x39, 0xf4, 0x5c, 0x04, 0xc8, 0x8a, 0x11, 0xda,
    0x59, 0x0b, 0xd2, 0x99, 0x06, 0xc6, 0x42, 0xa0, 0x0c, 0x18, 0x72, 0xdc, 0x88, 0x86, 0xd2, 0xd0,
    0xe3, 0x4f, 0x15, 0xa7, 0xad, 0xf5, 0xfe, 0x0b, 0x2e, 0x85, 0xd9, 0x68, 0xc8, 0xa2, 0xb2, 0x96,
    0x54, 0x25, 0x76, 0x87, 0x55, 0xc8, 0xa8, 0x00, 0xed, 0x2b, 0xd2, 0xbf, 0xeb, 0x21, 0x1f, 0xc9,
    0x4c, 0x60, 0xba, 0xc0, 0x8c, 0xb7, 0xfe, 0xfa, 0xfe, 0x1a, 0x83, 0x1e, 0x70, 0x95, 0xcc, 0x13,
    0x97, 0x1c, 0xc5, 0x58, 0x30, 0xca, 0x4e, 0x7b, 0x42, 0xa4, 0xaa, 0xfa, 0x63, 0x54, 0xee, 0x87,
    0x1c, 0x30, 0x33, 0xc7, 0x45, 0x52, 0xe6, 0x8f, 0x01, 0x25, 0xe6, 0xfd, 0x66, 0xc7, 0xcd, 0x54,
    0xd2, 0xbb, 0xca, 0x56, 0xda, 0x57, 0x62, 0x1b, 0x3e, 0xc2, 0xe1, 0xed, 0xf8, 0xd6, 0xba, 0x5c,
    0xf4, 0x86, 0x55, 0x82, 0x7e, 0x8f, 0x61, 0x29, 0x93, 0xec, 0xdb, 0x77, 0x19, 0xc2, 0x62, 0x8f,
    0x59, 0xff, 0x8f, 0xf4, 0x65, 0xc7, 0xdc, 0x29, 0x3d, 0x6f, 0xfe, 0x31, 0xfc, 0x3f, 0x93, 0xe3,
    0x91, 0x90, 0xbd, 0x55, 0x17, 0x9f, 0xcf, 0x39, 0x95, 0xbb, 0xef, 0x4e, 0xe6, 0xce, 0x30, 0x36,
    0x70, 0x5f, 0x6c, 0x23, 0xc1, 0x5f, 0x76, 0x4c, 0x56, 0xc6, 0x2a, 0x38, 0x6b, 0x26, 0x3b, 0x0a,
    0x27, 0xff, 0x0c, 0x33, 0xd5, 0x7e, 0xaf, 0xb4, 0x35, 0xf7, 0x5a, 0x55, 0xfb, 0x6f, 0xd0, 0x10,
    0x66, 0xaa, 0x2c, 0x2b, 0xc9, 0xfb, 0x83, 0x26, 0x02, 0xd0, 0x9e, 0x64, 0x70, 0x23, 0xff, 0x0f,
    0x0a, 0x5a, 0xe3, 0x77
};
#endif

PyTypeObject *init_KCalendarCore_Incidence(PyObject *enclosingClass)
{
    auto &typeStruct = SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_IDX];
    if (typeStruct.type != nullptr)
        return typeStruct.type;

    auto *base1 = reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]));
    auto *base2 = reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Recurrence_RecurrenceObserver_IDX]));
    Shiboken::AutoDecRef Sbk_KCalendarCore_Incidence_Type_bases(PyTuple_Pack(2, base1, base2));

    PyTypeObject *pyType = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "Incidence",
        "KCalendarCore::Incidence*",
        &Sbk_KCalendarCore_Incidence_spec,
        &Shiboken::callCppDestructor< KCalendarCore::Incidence >,
        Sbk_KCalendarCore_Incidence_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass);
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, KCalendarCore_Incidence_SignatureStrings);
#else
    InitSignatureBytes(pyType, KCalendarCore_Incidence_SignatureBytes, KCalendarCore_Incidence_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_KCalendarCore_Incidence_PropertyStrings);
    typeStruct.type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        Incidence_PythonToCpp_Incidence_PTR,
        is_Incidence_PythonToCpp_Incidence_PTR_Convertible,
        Incidence_PTR_CppToPython_Incidence);

    Shiboken::Conversions::registerConverterName(converter, "KCalendarCore::Incidence");
    Shiboken::Conversions::registerConverterName(converter, "KCalendarCore::Incidence*");
    Shiboken::Conversions::registerConverterName(converter, "KCalendarCore::Incidence&");
    Shiboken::Conversions::registerConverterAlias(converter, "Incidence");
    Shiboken::Conversions::registerConverterAlias(converter, "Incidence*");
    Shiboken::Conversions::registerConverterAlias(converter, "Incidence&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::KCalendarCore::Incidence).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(IncidenceWrapper).name());

    MultipleInheritanceInitFunction func = Sbk_KCalendarCore_Incidence_mi_init;
    Shiboken::ObjectType::setMultipleInheritanceFunction(Sbk_KCalendarCore_Incidence_TypeF(), func);
    Shiboken::ObjectType::setCastFunction(Sbk_KCalendarCore_Incidence_TypeF(), &Sbk_KCalendarCore_IncidenceSpecialCastFunction);
    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(pyType, &Sbk_KCalendarCore_Incidence_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_KCalendarCore_Incidence_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    [[maybe_unused]] PyTypeObject *EType{};

    // Initialization of enum 'Status'.
    const char *Status_Initializer[] = {
        "StatusNone",
        "StatusTentative",
        "StatusConfirmed",
        "StatusCompleted",
        "StatusNeedsAction",
        "StatusCanceled",
        "StatusInProcess",
        "StatusDraft",
        "StatusFinal",
        "StatusX",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Status_InitializerValues[] = {
        uint8_t(KCalendarCore::Incidence::Status::StatusNone),        //  0x00  0
        uint8_t(KCalendarCore::Incidence::Status::StatusTentative),   //  0x01  1
        uint8_t(KCalendarCore::Incidence::Status::StatusConfirmed),   //  0x02  2
        uint8_t(KCalendarCore::Incidence::Status::StatusCompleted),   //  0x03  3
        uint8_t(KCalendarCore::Incidence::Status::StatusNeedsAction), //  0x04  4
        uint8_t(KCalendarCore::Incidence::Status::StatusCanceled),    //  0x05  5
        uint8_t(KCalendarCore::Incidence::Status::StatusInProcess),   //  0x06  6
        uint8_t(KCalendarCore::Incidence::Status::StatusDraft),       //  0x07  7
        uint8_t(KCalendarCore::Incidence::Status::StatusFinal),       //  0x08  8
        uint8_t(KCalendarCore::Incidence::Status::StatusX)            //  0x09  9
        };
    EType = Shiboken::Enum::createPythonEnum(pyType,
        "1:KCalendarCore.KCalendarCore.Incidence.Status",
        Status_Initializer, Status_InitializerValues);
    SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_Status_IDX].type = EType;
    // Register converter for enum 'KCalendarCore::Incidence::Status'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            KCalendarCore_Incidence_Status_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_KCalendarCore_Incidence_Status,
            is_Enum_PythonToCpp_KCalendarCore_Incidence_Status_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "KCalendarCore::Incidence::Status");
        Shiboken::Conversions::registerConverterAlias(converter, "Incidence::Status");
        Shiboken::Conversions::registerConverterAlias(converter, "Status");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Status' enum.

    // Initialization of enum 'Secrecy'.
    const char *Secrecy_Initializer[] = {
        "SecrecyPublic",
        "SecrecyPrivate",
        "SecrecyConfidential",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Secrecy_InitializerValues[] = {
        uint8_t(KCalendarCore::Incidence::Secrecy::SecrecyPublic),      //  0x00  0
        uint8_t(KCalendarCore::Incidence::Secrecy::SecrecyPrivate),     //  0x01  1
        uint8_t(KCalendarCore::Incidence::Secrecy::SecrecyConfidential) //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(pyType,
        "1:KCalendarCore.KCalendarCore.Incidence.Secrecy",
        Secrecy_Initializer, Secrecy_InitializerValues);
    SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_Secrecy_IDX].type = EType;
    // Register converter for enum 'KCalendarCore::Incidence::Secrecy'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            KCalendarCore_Incidence_Secrecy_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_KCalendarCore_Incidence_Secrecy,
            is_Enum_PythonToCpp_KCalendarCore_Incidence_Secrecy_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "KCalendarCore::Incidence::Secrecy");
        Shiboken::Conversions::registerConverterAlias(converter, "Incidence::Secrecy");
        Shiboken::Conversions::registerConverterAlias(converter, "Secrecy");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Secrecy' enum.

    // Initialization of enum 'RelType'.
    const char *RelType_Initializer[] = {
        "RelTypeParent",
        "RelTypeChild",
        "RelTypeSibling",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t RelType_InitializerValues[] = {
        uint8_t(KCalendarCore::Incidence::RelType::RelTypeParent), //  0x00  0
        uint8_t(KCalendarCore::Incidence::RelType::RelTypeChild),  //  0x01  1
        uint8_t(KCalendarCore::Incidence::RelType::RelTypeSibling) //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(pyType,
        "1:KCalendarCore.KCalendarCore.Incidence.RelType",
        RelType_Initializer, RelType_InitializerValues);
    SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Incidence_RelType_IDX].type = EType;
    // Register converter for enum 'KCalendarCore::Incidence::RelType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            KCalendarCore_Incidence_RelType_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_KCalendarCore_Incidence_RelType,
            is_Enum_PythonToCpp_KCalendarCore_Incidence_RelType_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "KCalendarCore::Incidence::RelType");
        Shiboken::Conversions::registerConverterAlias(converter, "Incidence::RelType");
        Shiboken::Conversions::registerConverterAlias(converter, "RelType");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'RelType' enum.

    qRegisterMetaType< ::KCalendarCore::Incidence *>();
    qRegisterMetaType< ::KCalendarCore::Incidence::Status >("Incidence::Status");
    qRegisterMetaType< ::KCalendarCore::Incidence::Status >("KCalendarCore::Incidence::Status");
    qRegisterMetaType< ::KCalendarCore::Incidence::Secrecy >("Incidence::Secrecy");
    qRegisterMetaType< ::KCalendarCore::Incidence::Secrecy >("KCalendarCore::Incidence::Secrecy");
    qRegisterMetaType< ::KCalendarCore::Incidence::RelType >("Incidence::RelType");
    qRegisterMetaType< ::KCalendarCore::Incidence::RelType >("KCalendarCore::Incidence::RelType");

    return pyType;
}
